@@ -1,9 +1,12 @@
 import graphene
 from django.contrib.contenttypes.models import ContentType
+from django.db.models import Q
 from django.dispatch import receiver
 from django.utils.translation import gettext_lazy as _
 from graphene_django.types import DjangoObjectType
-from graphql.error import GraphQLLocatedError
+from graphql.error import GraphQLError, GraphQLLocatedError
+
+from ..utils import resolve_site
 
 try:
     from wagtail.models import Page as WagtailPage
@@ -224,6 +227,28 @@ def get_specific_page(
     return page
 
 
+def get_site_filter(info, **kwargs):
+    site_hostname = kwargs.pop("site", None)
+    in_current_site = kwargs.get("in_site", False)
+
+    if site_hostname is not None and in_current_site:
+        raise GraphQLError(
+            "The 'site' and 'in_site' filters cannot be used at the same time."
+        )
+
+    if site_hostname is not None:
+        try:
+            return resolve_site(site_hostname)
+        except Site.MultipleObjectsReturned:
+            raise GraphQLError(
+                "Your 'site' filter value of '{}' returned multiple sites. Try adding a port number (for example: '{}:80').".format(
+                    site_hostname, site_hostname
+                )
+            )
+    elif in_current_site:
+        return Site.find_for_request(info.context)
+
+
 def PagesQuery():
     # Add base type to registry
     registry.pages[type(WagtailPage)] = Page
@@ -233,13 +258,34 @@ def PagesQuery():
             graphene.NonNull(lambda: PageInterface),
             content_type=graphene.Argument(
                 graphene.String,
-                description=_("Filter by content type. Uses the `app.Model` notation."),
+                description=_(
+                    "Filter by content type. Uses the `app.Model` notation. Accepts a comma separated list of content types."
+                ),
             ),
             in_site=graphene.Argument(
                 graphene.Boolean,
                 description=_("Filter to pages in the current site only."),
                 default_value=False,
             ),
+            site=graphene.Argument(
+                graphene.String,
+                description=_("Filter to pages in the give site."),
+            ),
+            ancestor=graphene.Argument(
+                graphene.ID,
+                description=_(
+                    "Filter to pages that are descendants of the given page."
+                ),
+                required=False,
+            ),
+            parent=graphene.Argument(
+                graphene.ID,
+                description=_(
+                    "Filter to pages that are children of the given page. "
+                    "When using both `parent` and `ancestor`, then `parent` will take precendence."
+                ),
+                required=False,
+            ),
             enable_search=True,
             required=True,
         )
@@ -271,24 +317,43 @@ def PagesQuery():
                 description=_("Filter to pages in the current site only."),
                 default_value=False,
             ),
+            site=graphene.Argument(
+                graphene.String,
+                description=_("Filter to pages in the give site."),
+            ),
         )
 
         # Return all pages in site, ideally specific.
         def resolve_pages(self, info, **kwargs):
-            pages = (
-                WagtailPage.objects.live().public().filter(depth__gt=1).specific()
-            )  # no need to the root page
+            qs = WagtailPage.objects.all()
 
-            if kwargs.get("in_site", False):
-                site = Site.find_for_request(info.context)
+            try:
+                if kwargs.get("parent"):
+                    qs = WagtailPage.objects.get(id=kwargs.get("parent")).get_children()
+                elif kwargs.get("ancestor"):
+                    qs = WagtailPage.objects.get(
+                        id=kwargs.get("ancestor")
+                    ).get_descendants()
+            except WagtailPage.DoesNotExist:
+                qs = WagtailPage.objects.none()
+
+            # no need to the root page
+            pages = qs.live().public().filter(depth__gt=1).specific()
+
+            site = get_site_filter(info, **kwargs)
+            if site is not None:
                 pages = pages.in_site(site)
 
             content_type = kwargs.pop("content_type", None)
-            if content_type:
-                app_label, model = content_type.strip().lower().split(".")
-                pages = pages.filter(
-                    content_type__app_label=app_label, content_type__model=model
-                )
+            content_types = content_type.split(",") if content_type else None
+            if content_types:
+                filters = Q()
+                for content_type in content_types:
+                    app_label, model = content_type.strip().lower().split(".")
+                    filters |= Q(
+                        content_type__app_label=app_label, content_type__model=model
+                    )
+                pages = pages.filter(filters)
 
             return resolve_queryset(pages, info, **kwargs)
 
@@ -300,9 +365,7 @@ def PagesQuery():
                 url_path=kwargs.get("url_path"),
                 token=kwargs.get("token"),
                 content_type=kwargs.get("content_type"),
-                site=Site.find_for_request(info.context)
-                if kwargs.get("in_site", False)
-                else None,
+                site=get_site_filter(info, **kwargs),
             )
 
     return Mixin
@@ -358,6 +421,10 @@ if has_channels:
                     description=_("Filter to pages in the current site only."),
                     default_value=False,
                 ),
+                site=graphene.Argument(
+                    graphene.String,
+                    description=_("Filter to pages in the give site."),
+                ),
             )
 
             def resolve_page(self, info, **kwargs):
@@ -367,9 +434,7 @@ if has_channels:
                     url_path=kwargs.get("url_path"),
                     token=kwargs.get("token"),
                     content_type=kwargs.get("content_type"),
-                    site=Site.find_for_request(info.context)
-                    if kwargs.get("in_site", False)
-                    else None,
+                    site=get_site_filter(info, **kwargs),
                 )
 
         return Mixin
