@@ -1,8 +1,9 @@
 import graphene
 from django.apps import apps
-from wagtail.documents.models import get_document_model
+from wagtail.documents import get_document_model
 from wagtail.images import get_image_model
 from wagtail.search.backends import get_search_backend
+
 from ..registry import registry
 
 
